@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2012-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include "gpaste-gdbus-macros.h"
@@ -27,7 +14,7 @@ struct _GPasteClient
     GDBusProxy parent_instance;
 };
 
-G_DEFINE_TYPE (GPasteClient, g_paste_client, G_TYPE_DBUS_PROXY)
+G_PASTE_DEFINE_TYPE (Client, client, G_TYPE_DBUS_PROXY)
 
 enum
 {
@@ -129,16 +116,16 @@ static guint64 signals[LAST_SIGNAL] = { 0 };
 /* Signals */
 /***********/
 
-#define HANDLE_SIGNAL(sig)                                  \
-    if (!g_strcmp0 (signal_name, G_PASTE_DAEMON_SIG_##sig)) \
-    {                                                       \
-        g_signal_emit (self,                                \
-                       signals[sig],                        \
-                       0, /* detail */                      \
-                       NULL);                               \
+#define HANDLE_SIGNAL(sig)                                         \
+    if (g_paste_str_equal (signal_name, G_PASTE_DAEMON_SIG_##sig)) \
+    {                                                              \
+        g_signal_emit (self,                                       \
+                       signals[sig],                               \
+                       0, /* detail */                             \
+                       NULL);                                      \
     }
 #define HANDLE_SIGNAL_WITH_DATA(sig, ans_type, get_data)                         \
-    if (!g_strcmp0 (signal_name, G_PASTE_DAEMON_SIG_##sig))                      \
+    if (g_paste_str_equal (signal_name, G_PASTE_DAEMON_SIG_##sig))               \
     {                                                                            \
         GVariantIter params_iter;                                                \
         g_variant_iter_init (&params_iter, parameters);                          \
@@ -190,8 +177,6 @@ compute_at_param (const guint64 *indexes,
  * @error: a #GError
  *
  * Display the about dialog
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_about_sync (GPasteClient *self,
@@ -207,8 +192,6 @@ g_paste_client_about_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Add an item to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add_sync (GPasteClient *self,
@@ -225,8 +208,6 @@ g_paste_client_add_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Add the file contents to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add_file_sync (GPasteClient *self,
@@ -252,8 +233,6 @@ g_paste_client_add_file_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Add the password to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add_password_sync (GPasteClient *self,
@@ -277,8 +256,6 @@ g_paste_client_add_password_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Backup the current history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_backup_history_sync (GPasteClient *self,
@@ -301,8 +278,6 @@ g_paste_client_backup_history_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Delete an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete_sync (GPasteClient *self,
@@ -319,8 +294,6 @@ g_paste_client_delete_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Delete an history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete_history_sync (GPasteClient *self,
@@ -337,8 +310,6 @@ g_paste_client_delete_history_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Delete the password from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete_password_sync (GPasteClient *self,
@@ -355,8 +326,6 @@ g_paste_client_delete_password_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Empty the history from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_empty_history_sync (GPasteClient *self,
@@ -547,8 +516,6 @@ g_paste_client_list_histories_sync (GPasteClient *self,
  *
  * If decoration is " and separator is , and entries are foo bar baz
  * result will be "foo","bar","baz"
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_merge_sync (GPasteClient  *self,
@@ -574,8 +541,6 @@ g_paste_client_merge_sync (GPasteClient  *self,
  * @error: a #GError
  *
  * Call this when the extension changes its state
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_on_extension_state_changed_sync (GPasteClient *self,
@@ -591,8 +556,6 @@ g_paste_client_on_extension_state_changed_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Reexecute the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_reexecute_sync (GPasteClient *self,
@@ -609,8 +572,6 @@ g_paste_client_reexecute_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Rename the password in the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_rename_password_sync (GPasteClient *self,
@@ -634,8 +595,6 @@ g_paste_client_rename_password_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Replace the contents of an item
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_replace_sync (GPasteClient *self,
@@ -678,8 +637,6 @@ g_paste_client_search_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Select an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_select_sync (GPasteClient *self,
@@ -697,8 +654,6 @@ g_paste_client_select_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Set the item as password
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_set_password_sync (GPasteClient *self,
@@ -720,8 +675,6 @@ g_paste_client_set_password_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Emit the ShowHistory signal
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_show_history_sync (GPasteClient *self,
@@ -736,8 +689,6 @@ g_paste_client_show_history_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Switch to another history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_switch_history_sync (GPasteClient *self,
@@ -754,8 +705,6 @@ g_paste_client_switch_history_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Change the tracking state of the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_track_sync (GPasteClient *self,
@@ -772,8 +721,6 @@ g_paste_client_track_sync (GPasteClient *self,
  * @error: a #GError
  *
  * Upload an item to a pastebin service
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_upload_sync (GPasteClient *self,
@@ -795,8 +742,6 @@ g_paste_client_upload_sync (GPasteClient *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Display the about dialog
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_about (GPasteClient       *self,
@@ -815,8 +760,6 @@ g_paste_client_about (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Add an item to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add (GPasteClient       *self,
@@ -836,8 +779,6 @@ g_paste_client_add (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Add the file contents to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add_file (GPasteClient       *self,
@@ -866,8 +807,6 @@ g_paste_client_add_file (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Add the password to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add_password (GPasteClient       *self,
@@ -894,8 +833,6 @@ g_paste_client_add_password (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Backup the current history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_backup_history (GPasteClient       *self,
@@ -921,8 +858,6 @@ g_paste_client_backup_history (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Delete an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete (GPasteClient       *self,
@@ -942,8 +877,6 @@ g_paste_client_delete (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Delete an history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete_history (GPasteClient       *self,
@@ -963,8 +896,6 @@ g_paste_client_delete_history (GPasteClient       *self,
  * @user_data: The data to pass to @callback.
  *
  * Delete the password from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete_password (GPasteClient       *self,
@@ -984,8 +915,6 @@ g_paste_client_delete_password (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Empty the history from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_empty_history (GPasteClient       *self,
@@ -1005,8 +934,6 @@ g_paste_client_empty_history (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Get an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_get_element (GPasteClient       *self,
@@ -1026,8 +953,6 @@ g_paste_client_get_element (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Get the kind of an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_get_element_kind (GPasteClient       *self,
@@ -1048,8 +973,6 @@ g_paste_client_get_element_kind (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Get some items from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_get_elements (GPasteClient       *self,
@@ -1070,8 +993,6 @@ g_paste_client_get_elements (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Get the history from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_get_history (GPasteClient       *self,
@@ -1089,8 +1010,6 @@ g_paste_client_get_history (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Get the name of the history from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_get_history_name (GPasteClient       *self,
@@ -1109,8 +1028,6 @@ g_paste_client_get_history_name (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Get the history isize from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_get_history_size (GPasteClient       *self,
@@ -1130,8 +1047,6 @@ g_paste_client_get_history_size (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Get an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_get_raw_element (GPasteClient       *self,
@@ -1150,8 +1065,6 @@ g_paste_client_get_raw_element (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Get the history from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_get_raw_history (GPasteClient       *self,
@@ -1169,8 +1082,6 @@ g_paste_client_get_raw_history (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * List all available hisotries
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_list_histories (GPasteClient       *self,
@@ -1195,8 +1106,6 @@ g_paste_client_list_histories (GPasteClient       *self,
  *
  * If decoration is " and separator is , and entries are foo bar baz
  * result will be "foo","bar","baz"
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_merge (GPasteClient       *self,
@@ -1225,8 +1134,6 @@ g_paste_client_merge (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Call this when the extension changes its state
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_on_extension_state_changed (GPasteClient       *self,
@@ -1245,8 +1152,6 @@ g_paste_client_on_extension_state_changed (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Reexecute the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_reexecute (GPasteClient       *self,
@@ -1266,8 +1171,6 @@ g_paste_client_reexecute (GPasteClient       *self,
  * @user_data: The data to pass to @callback.
  *
  * Rename the password in the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_rename_password (GPasteClient       *self,
@@ -1294,8 +1197,6 @@ g_paste_client_rename_password (GPasteClient       *self,
  * @user_data: The data to pass to @callback.
  *
  * Replace the contents of an item
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_replace (GPasteClient       *self,
@@ -1321,8 +1222,6 @@ g_paste_client_replace (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Search for items matching @pattern in history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_search (GPasteClient       *self,
@@ -1342,8 +1241,6 @@ g_paste_client_search (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Select an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_select (GPasteClient       *self,
@@ -1364,8 +1261,6 @@ g_paste_client_select (GPasteClient       *self,
  * @user_data: The data to pass to @callback.
  *
  * Set the item as password
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_set_password (GPasteClient       *self,
@@ -1390,8 +1285,6 @@ g_paste_client_set_password (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Emit the ShowHistory signal
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_show_history (GPasteClient       *self,
@@ -1410,8 +1303,6 @@ g_paste_client_show_history (GPasteClient       *self,
  * @user_data: (nullable):The data to pass to @callback.
  *
  * Switch to another history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_switch_history (GPasteClient       *self,
@@ -1431,8 +1322,6 @@ g_paste_client_switch_history (GPasteClient       *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Change the tracking state of the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_track (GPasteClient *self,
@@ -1452,8 +1341,6 @@ g_paste_client_track (GPasteClient *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Upload an item to a pastebin service
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_upload (GPasteClient       *self,
@@ -1475,8 +1362,6 @@ g_paste_client_upload (GPasteClient       *self,
  * @error: a #GError
  *
  * Display the about dialog
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_about_finish (GPasteClient *self,
@@ -1493,8 +1378,6 @@ g_paste_client_about_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Add an item to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add_finish (GPasteClient *self,
@@ -1511,8 +1394,6 @@ g_paste_client_add_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Add the file contents to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add_file_finish (GPasteClient *self,
@@ -1529,8 +1410,6 @@ g_paste_client_add_file_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Add the password to the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_add_password_finish (GPasteClient *self,
@@ -1547,8 +1426,6 @@ g_paste_client_add_password_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Backup the current history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_backup_history_finish (GPasteClient *self,
@@ -1565,8 +1442,6 @@ g_paste_client_backup_history_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Delete an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete_finish (GPasteClient *self,
@@ -1583,8 +1458,6 @@ g_paste_client_delete_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Delete an history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete_history_finish (GPasteClient *self,
@@ -1601,8 +1474,6 @@ g_paste_client_delete_history_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Delete the password from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_delete_password_finish (GPasteClient *self,
@@ -1619,8 +1490,6 @@ g_paste_client_delete_password_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Empty the history from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_empty_history_finish (GPasteClient *self,
@@ -1810,8 +1679,6 @@ g_paste_client_list_histories_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Merge some history entries
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_merge_finish (GPasteClient *self,
@@ -1828,8 +1695,6 @@ g_paste_client_merge_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Call this when the extension changes its state
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_on_extension_state_changed_finish (GPasteClient *self,
@@ -1846,8 +1711,6 @@ g_paste_client_on_extension_state_changed_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Reexecute the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_reexecute_finish (GPasteClient *self,
@@ -1864,8 +1727,6 @@ g_paste_client_reexecute_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Rename the password in the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_rename_password_finish (GPasteClient *self,
@@ -1882,8 +1743,6 @@ g_paste_client_rename_password_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Replace the contents of an item
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_replace_finish (GPasteClient *self,
@@ -1920,8 +1779,6 @@ g_paste_client_search_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Select an item from the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_select_finish (GPasteClient *self,
@@ -1938,8 +1795,6 @@ g_paste_client_select_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Set the item as password
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_set_password_finish (GPasteClient *self,
@@ -1956,8 +1811,6 @@ g_paste_client_set_password_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Emit the ShowHistory signal
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_show_history_finish (GPasteClient *self,
@@ -1974,8 +1827,6 @@ g_paste_client_show_history_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Switch to another history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_switch_history_finish (GPasteClient *self,
@@ -1992,8 +1843,6 @@ g_paste_client_switch_history_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Change the tracking state of the #GPasteDaemon
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_track_finish (GPasteClient *self,
@@ -2010,8 +1859,6 @@ g_paste_client_track_finish (GPasteClient *self,
  * @error: a #GError
  *
  * Upload an item to a pastebin service
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_upload_finish (GPasteClient *self,
@@ -2066,7 +1913,7 @@ g_paste_client_g_signal (GDBusProxy  *proxy,
     else HANDLE_SIGNAL_WITH_DATA (EMPTY_HISTORY,  const gchar *, g_variant_get_string (variant, NULL))
     else HANDLE_SIGNAL_WITH_DATA (SWITCH_HISTORY, const gchar *, g_variant_get_string (variant, NULL))
     else HANDLE_SIGNAL_WITH_DATA (TRACKING,       gboolean,      g_variant_get_boolean (variant))
-    else if (!g_strcmp0 (signal_name, G_PASTE_DAEMON_SIG_UPDATE))
+    else if (g_paste_str_equal (signal_name, G_PASTE_DAEMON_SIG_UPDATE))
     {
         GVariantIter params_iter;
         g_variant_iter_init (&params_iter, parameters);
@@ -2192,8 +2039,6 @@ g_paste_client_new_sync (GError **error)
  * @user_data: User data to pass to @callback.
  *
  * Create a new instance of #GPasteClient
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_client_new (GAsyncReadyCallback callback,
