@@ -23,27 +23,14 @@ enum
     C_LAST_SIGNAL
 };
 
-typedef enum
-{
-    CLIP_STATE_IDLE,
-    CLIP_STATE_WAITING,
-    CLIP_STATE_BUSY
-} ClipState;
-
 typedef struct
 {
-    GdkAtom         target;
     GtkClipboard   *real;
     GPasteSettings *settings;
     gchar          *text;
     gchar          *image_checksum;
 
     guint64         c_signals[C_LAST_SIGNAL];
-
-    /* GtkClipboard has a bug where it overrides an internal GMainLoop
-     * if we call gtk_clipboard_store twice in less than 10s, resulting
-     * in a g_main_loop_quit (NULL) call making GPaste crash */
-    ClipState       state;
 } GPasteClipboardPrivate;
 
 G_PASTE_DEFINE_TYPE_WITH_PRIVATE (Clipboard, clipboard, G_TYPE_OBJECT)
@@ -138,7 +125,7 @@ g_paste_clipboard_get_target (const GPasteClipboard *self)
 
     const GPasteClipboardPrivate *priv = _g_paste_clipboard_get_instance_private (self);
 
-    return priv->target;
+    return gtk_clipboard_get_selection (priv->real);
 }
 
 /**
@@ -184,7 +171,7 @@ g_paste_clipboard_private_set_text (GPasteClipboardPrivate *priv,
     g_free (priv->text);
     g_free (priv->image_checksum);
 
-    g_debug("%s: set text", gdk_atom_name (priv->target));
+    g_debug("%s: set text", gdk_atom_name (gtk_clipboard_get_selection (priv->real)));
 
     priv->text = g_strdup (text);
     priv->image_checksum = NULL;
@@ -234,7 +221,7 @@ g_paste_clipboard_on_text_ready (GtkClipboard *clipboard G_GNUC_UNUSED,
     }
 
     if (trim_items &&
-        priv->target == GDK_SELECTION_CLIPBOARD &&
+        gtk_clipboard_get_selection (priv->real) == GDK_SELECTION_CLIPBOARD &&
         !g_paste_str_equal (text, stripped))
             g_paste_clipboard_select_text (self, stripped);
     else
@@ -271,47 +258,6 @@ g_paste_clipboard_set_text (GPasteClipboard            *self,
                                 data);
 }
 
-static void g_paste_clipboard_private_store (GPasteClipboardPrivate *priv);
-
-static gboolean
-g_paste_clipboard_private_store_timeout (gpointer user_data)
-{
-    GPasteClipboardPrivate *priv = user_data;
-    gboolean waiting = (priv->state == CLIP_STATE_WAITING);
-
-    /* Reset us as IDLE */
-    priv->state = CLIP_STATE_IDLE;
-
-    /* If we were waiting, perform the store now */
-    if (waiting)
-        g_paste_clipboard_private_store (priv);
-
-    return G_SOURCE_REMOVE;
-}
-
-static void
-g_paste_clipboard_private_store (GPasteClipboardPrivate *priv)
-{
-    g_debug("%s: store", gdk_atom_name (priv->target));
-
-    switch (priv->state)
-    {
-    case CLIP_STATE_IDLE:
-        /* We're idle, store right now and mark us BUSY for 10 secs */
-        gtk_clipboard_store (priv->real);
-        priv->state = CLIP_STATE_BUSY;
-        g_timeout_add_seconds (10, g_paste_clipboard_private_store_timeout, priv);
-        break;
-    case CLIP_STATE_BUSY:
-        /* We're busy, wait until we're finished to store once more */
-        priv->state = CLIP_STATE_WAITING;
-        break;
-    case CLIP_STATE_WAITING:
-        /* We're already waiting, nothing to do */
-        break;
-    }
-}
-
 /**
  * g_paste_clipboard_select_text:
  * @self: a #GPasteClipboard instance
@@ -329,12 +275,11 @@ g_paste_clipboard_select_text (GPasteClipboard *self,
 
     GPasteClipboardPrivate *priv = g_paste_clipboard_get_instance_private (self);
 
-    g_debug("%s: select text", gdk_atom_name (priv->target));
+    g_debug("%s: select text", gdk_atom_name (gtk_clipboard_get_selection (priv->real)));
 
     /* Avoid cycling twice as gtk_clipboard_set_text will make the clipboards manager react */
     g_paste_clipboard_private_set_text (priv, text);
     gtk_clipboard_set_text (priv->real, text, -1);
-    g_paste_clipboard_private_store (priv);
 }
 
 static void
@@ -399,7 +344,7 @@ g_paste_clipboard_private_select_uris (GPasteClipboardPrivate *priv,
     GtkClipboard *real = priv->real;
     g_autoptr (GtkTargetList) target_list = gtk_target_list_new (NULL, 0);
 
-    g_debug("%s: select uris", gdk_atom_name (priv->target));
+    g_debug("%s: select uris", gdk_atom_name (gtk_clipboard_get_selection (priv->real)));
 
     g_paste_clipboard_private_set_text (priv, g_paste_item_get_real_value (_G_PASTE_ITEM (item)));
 
@@ -415,8 +360,6 @@ g_paste_clipboard_private_select_uris (GPasteClipboardPrivate *priv,
                                   g_paste_clipboard_get_clipboard_data,
                                   g_paste_clipboard_clear_clipboard_data,
                                   g_object_ref (item));
-    g_paste_clipboard_private_store (priv);
-
     gtk_target_table_free (targets, n_targets);
 }
 
@@ -437,7 +380,7 @@ g_paste_clipboard_clear (GPasteClipboard *self)
     if (!priv->text && !priv->image_checksum)
         return;
 
-    g_debug("%s: clear", gdk_atom_name (priv->target));
+    g_debug("%s: clear", gdk_atom_name (gtk_clipboard_get_selection (priv->real)));
 
     g_clear_pointer (&priv->text, g_free);
     g_clear_pointer (&priv->image_checksum, g_free);
@@ -445,6 +388,24 @@ g_paste_clipboard_clear (GPasteClipboard *self)
     gtk_clipboard_clear (priv->real);
 }
 
+/**
+ * g_paste_clipboard_store:
+ * @self: a #GPasteClipboard instance
+ *
+ * Store the contents of the clipboard before exiting
+ */
+G_PASTE_VISIBLE void
+g_paste_clipboard_store (GPasteClipboard *self)
+{
+    g_return_if_fail (_G_PASTE_IS_CLIPBOARD (self));
+
+    GPasteClipboardPrivate *priv = g_paste_clipboard_get_instance_private (self);
+
+    g_debug("%s: store", gdk_atom_name (gtk_clipboard_get_selection (priv->real)));
+
+    gtk_clipboard_store (priv->real);
+}
+
 /**
  * g_paste_clipboard_get_image_checksum:
  * @self: a #GPasteClipboard instance
@@ -483,7 +444,7 @@ g_paste_clipboard_private_select_image (GPasteClipboardPrivate *priv,
 
     GtkClipboard *real = priv->real;
 
-    g_debug("%s: select image", gdk_atom_name (priv->target));
+    g_debug("%s: select image", gdk_atom_name (gtk_clipboard_get_selection (priv->real)));
 
     g_paste_clipboard_private_set_image_checksum (priv, checksum);
     gtk_clipboard_set_image (real, image);
@@ -574,7 +535,7 @@ g_paste_clipboard_select_item (GPasteClipboard *self,
 
     GPasteClipboardPrivate *priv = g_paste_clipboard_get_instance_private (self);
 
-    g_debug("%s: select item", gdk_atom_name (priv->target));
+    g_debug("%s: select item", gdk_atom_name (gtk_clipboard_get_selection (priv->real)));
 
     if (_G_PASTE_IS_IMAGE_ITEM (item))
     {
@@ -632,7 +593,7 @@ g_paste_clipboard_owner_change (GtkClipboard        *clipboard G_GNUC_UNUSED,
     GPasteClipboard *self = user_data;
     GPasteClipboardPrivate *priv = g_paste_clipboard_get_instance_private (self);
 
-    g_debug("%s: owner change", gdk_atom_name (priv->target));
+    g_debug("%s: owner change", gdk_atom_name (gtk_clipboard_get_selection (priv->real)));
 
     g_signal_emit (self,
 		   signals[OWNER_CHANGE],
@@ -739,11 +700,8 @@ g_paste_clipboard_class_init (GPasteClipboardClass *klass)
 }
 
 static void
-g_paste_clipboard_init (GPasteClipboard *self)
+g_paste_clipboard_init (GPasteClipboard *self G_GNUC_UNUSED)
 {
-    GPasteClipboardPrivate *priv = g_paste_clipboard_get_instance_private (self);
-
-    priv->state = CLIP_STATE_IDLE;
 }
 
 /**
@@ -764,12 +722,9 @@ g_paste_clipboard_new (GdkAtom         target,
 
     GPasteClipboard *self = g_object_new (G_PASTE_TYPE_CLIPBOARD, NULL);
     GPasteClipboardPrivate *priv = g_paste_clipboard_get_instance_private (self);
-
-    priv->target = target;
-    priv->settings = g_object_ref (settings);
-
     GtkClipboard *real = priv->real = gtk_clipboard_get (target);
 
+    priv->settings = g_object_ref (settings);
     priv->c_signals[C_OWNER_CHANGE] = g_signal_connect (real,
                                                         "owner-change",
                                                         G_CALLBACK (g_paste_clipboard_owner_change),
