@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2011-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #if !defined (__G_PASTE_H_INSIDE__) && !defined (G_PASTE_COMPILATION)
@@ -53,14 +40,15 @@ void          g_paste_clipboard_set_text    (GPasteClipboard            *self,
 void          g_paste_clipboard_select_text (GPasteClipboard *self,
                                              const gchar     *text);
 void          g_paste_clipboard_clear       (GPasteClipboard *self);
+void          g_paste_clipboard_store       (GPasteClipboard *self);
 const gchar  *g_paste_clipboard_get_image_checksum (const GPasteClipboard *self);
 void          g_paste_clipboard_set_image          (GPasteClipboard             *self,
                                                     GPasteClipboardImageCallback callback,
                                                     gpointer                     user_data);
-gboolean      g_paste_clipboard_select_item        (GPasteClipboard  *self,
-                                                    const GPasteItem *item);
-void          g_paste_clipboard_ensure_not_empty   (GPasteClipboard *self,
-                                                    GPasteHistory   *history);
+void          g_paste_clipboard_select_item        (GPasteClipboard *self,
+                                                    GPasteItem      *item);
+void          g_paste_clipboard_ensure_not_empty   (GPasteClipboard     *self,
+                                                    const GPasteHistory *history);
 
 GPasteClipboard *g_paste_clipboard_new (GdkAtom         target,
                                         GPasteSettings *settings);
