@@ -73,7 +73,7 @@ g_paste_clipboards_manager_sync_ready (GtkClipboard *clipboard G_GNUC_UNUSED,
                                        gpointer user_data)
 {
     if (text)
-        gtk_clipboard_set_text (user_data, text, -1);
+        g_paste_clipboard_select_text (user_data, text);
 }
 
 /**
@@ -92,7 +92,8 @@ g_paste_clipboards_manager_sync_from_to (GPasteClipboardsManager *self,
     g_return_if_fail (_G_PASTE_IS_CLIPBOARDS_MANAGER (self));
 
     const GPasteClipboardsManagerPrivate *priv = _g_paste_clipboards_manager_get_instance_private (self);
-    GtkClipboard *_from = NULL, *_to = NULL;
+    GtkClipboard *_from = NULL;
+    GPasteClipboard *_to = NULL;
 
     g_debug ("clipboards-manager: sync from %s to %s", gdk_atom_name (from), gdk_atom_name (to));
 
@@ -105,7 +106,7 @@ g_paste_clipboards_manager_sync_from_to (GPasteClipboardsManager *self,
         if (cur == from)
             _from = g_paste_clipboard_get_real (clip);
         else if (cur == to)
-            _to = g_paste_clipboard_get_real (clip);
+            _to = clip;
     }
 
     if (_from && _to)
@@ -135,6 +136,8 @@ g_paste_clipboards_manager_notify_finish (GPasteClipboardsManagerPrivate *priv,
 
     if (synchronized_text)
     {
+        g_debug ("clipboards-manager: synchronizing clipboards");
+
         for (GSList *_clipboard = priv->clipboards; _clipboard; _clipboard = g_slist_next (_clipboard))
         {
             _Clipboard *_clip = _clipboard->data;
@@ -252,19 +255,26 @@ g_paste_clipboards_manager_targets_ready (GtkClipboard     *clipboard G_GNUC_UNU
 }
 
 static void
-g_paste_clipboards_manager_notify (GPasteClipboard *clipboard,
-                                   GdkEvent        *event G_GNUC_UNUSED,
-                                   gpointer         user_data)
+g_paste_clipboards_manager_notify (GPasteClipboard     *clipboard,
+                                   GdkEventOwnerChange *event,
+                                   gpointer             user_data)
 {
     GPasteClipboardsManagerPrivate *priv = user_data;
 
+    if (event->reason != GDK_OWNER_CHANGE_NEW_OWNER)
+    {
+        g_debug ("clipboards-manager: ignoring deletion event");
+        return;
+    }
+
     g_debug ("clipboards-manager: notify");
 
     GPasteSettings *settings = priv->settings;
     GdkAtom atom = g_paste_clipboard_get_target (clipboard);
-    gboolean track = ((atom != GDK_SELECTION_PRIMARY || g_paste_settings_get_primary_to_history (settings)) &&
-                      g_paste_settings_get_track_changes (settings));
-
+    gboolean track = (g_paste_settings_get_track_changes (settings) &&
+                          (atom != GDK_SELECTION_PRIMARY ||                          // We're not primary
+                           g_paste_settings_get_primary_to_history (settings) ||     // Or we asked that primary affects clipboard
+                           g_paste_settings_get_synchronize_clipboards (settings))); // Or primary and clipboards are synchronized hence primary will affect history through clipboard
     GPasteClipboardsManagerCallbackData *data = g_new (GPasteClipboardsManagerCallbackData, 1);
 
     data->priv = priv;
@@ -327,6 +337,29 @@ g_paste_clipboards_manager_select (GPasteClipboardsManager *self,
     }
 }
 
+/**
+ * g_paste_clipboards_manager_store:
+ * @self: a #GPasteClipboardsManager instance
+ *
+ * Store clipboards contents before exiting
+ */
+G_PASTE_VISIBLE void
+g_paste_clipboards_manager_store (GPasteClipboardsManager *self)
+{
+    g_return_if_fail (_G_PASTE_IS_CLIPBOARDS_MANAGER (self));
+
+    const GPasteClipboardsManagerPrivate *priv = _g_paste_clipboards_manager_get_instance_private (self);
+
+    g_debug ("clipboards-manager: store");
+
+    for (GSList *clipboard = priv->clipboards; clipboard; clipboard = g_slist_next (clipboard))
+    {
+        _Clipboard *clip = clipboard->data;
+
+        g_paste_clipboard_store (clip->clipboard);
+    }
+}
+
 static void
 on_item_selected (GPasteClipboardsManager *self,
                   GPasteItem              *item,
