@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2011-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include <gpaste-history.h>
@@ -29,10 +16,17 @@ struct _GPasteHistory
     GObject parent_instance;
 };
 
+enum
+{
+    C_CHANGED,
+
+    C_LAST_SIGNAL
+};
+
 typedef struct
 {
     GPasteSettings *settings;
-    GSList         *history;
+    GList          *history;
     guint64         size;
 
     gchar          *name;
@@ -41,10 +35,10 @@ typedef struct
     guint64         biggest_index;
     guint64         biggest_size;
 
-    gulong          changed_signal;
+    guint64         c_signals[C_LAST_SIGNAL];
 } GPasteHistoryPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (GPasteHistory, g_paste_history, G_TYPE_OBJECT)
+G_PASTE_DEFINE_TYPE_WITH_PRIVATE (History, history, G_TYPE_OBJECT)
 
 enum
 {
@@ -65,7 +59,7 @@ g_paste_history_private_elect_new_biggest (GPasteHistoryPrivate *priv)
     priv->biggest_index = 0;
     priv->biggest_size = 0;
 
-    GSList *history = priv->history;
+    GList *history = priv->history;
 
     if (history)
     {
@@ -85,13 +79,13 @@ g_paste_history_private_elect_new_biggest (GPasteHistoryPrivate *priv)
     }
 }
 
-static GSList *
+static void
 g_paste_history_private_remove (GPasteHistoryPrivate *priv,
-                                GSList               *elem,
+                                GList                *elem,
                                 gboolean              remove_leftovers)
 {
     if (!elem)
-        return NULL;
+        return;
 
     GPasteItem *item = elem->data;
 
@@ -99,7 +93,7 @@ g_paste_history_private_remove (GPasteHistoryPrivate *priv,
 
     if (remove_leftovers)
     {
-        if (G_PASTE_IS_IMAGE_ITEM (item))
+        if (_G_PASTE_IS_IMAGE_ITEM (item))
         {
             g_autoptr (GFile) image = g_file_new_for_path (g_paste_item_get_value (item));
             g_file_delete (image,
@@ -108,7 +102,7 @@ g_paste_history_private_remove (GPasteHistoryPrivate *priv,
         }
         g_object_unref (item);
     }
-    return g_slist_delete_link (elem, elem);
+    priv->history = g_list_delete_link (priv->history, elem);
 }
 
 static void
@@ -161,7 +155,7 @@ g_paste_history_activate_first (GPasteHistory *self,
                                 gboolean       select)
 {
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
-    GSList *history = priv->history;
+    GList *history = priv->history;
 
     if (!history)
         return;
@@ -183,9 +177,11 @@ g_paste_history_private_check_memory_usage (GPasteHistoryPrivate *priv)
 
     while (priv->size > max_memory && !priv->biggest_index)
     {
-        GSList *prev = g_slist_nth (priv->history, priv->biggest_index - 1);
-        g_return_if_fail (prev);
-        prev->next = g_paste_history_private_remove (priv, g_slist_next (prev), TRUE);
+        GList *biggest = g_list_nth (priv->history, priv->biggest_index);
+
+        g_return_if_fail (biggest);
+
+        g_paste_history_private_remove (priv, biggest, TRUE);
         g_paste_history_private_elect_new_biggest (priv);
     }
 }
@@ -193,21 +189,21 @@ g_paste_history_private_check_memory_usage (GPasteHistoryPrivate *priv)
 static void
 g_paste_history_private_check_size (GPasteHistoryPrivate *priv)
 {
-    GSList *history = priv->history;
+    GList *history = priv->history;
     guint64 max_history_size = g_paste_settings_get_max_history_size (priv->settings);
-    guint64 length = g_slist_length (history);
+    guint64 length = g_list_length (history);
 
     if (length > max_history_size)
     {
-        GSList *previous = g_slist_nth (history, max_history_size - 1);
-        g_return_if_fail (previous);
-        history = g_slist_next (previous);
-        previous->next = NULL;
+        history = g_list_nth (history, max_history_size);
+        g_return_if_fail (history);
+        history->prev->next = NULL;
+        history->prev = NULL;
 
-        for (GSList *_history = history; _history; _history = g_slist_next (_history))
+        for (GList *_history = history; _history; _history = g_list_next (_history))
             priv->size -= g_paste_item_get_size (_history->data);
-        g_slist_free_full (history,
-                           g_object_unref);
+        g_list_free_full (history,
+                          g_object_unref);
     }
 }
 
@@ -217,8 +213,8 @@ g_paste_history_private_is_growing_line (GPasteHistoryPrivate *priv,
                                          GPasteItem           *new)
 {
     if (!(g_paste_settings_get_growing_lines (priv->settings) &&
-        G_PASTE_IS_TEXT_ITEM (old) && G_PASTE_IS_TEXT_ITEM (new) &&
-        !G_PASTE_IS_PASSWORD_ITEM (old) && !G_PASTE_IS_PASSWORD_ITEM (new)))
+        _G_PASTE_IS_TEXT_ITEM (old) && _G_PASTE_IS_TEXT_ITEM (new) &&
+        !_G_PASTE_IS_PASSWORD_ITEM (old) && !_G_PASTE_IS_PASSWORD_ITEM (new)))
             return FALSE;
 
     const gchar *n = g_paste_item_get_value (new);
@@ -233,22 +229,21 @@ g_paste_history_private_is_growing_line (GPasteHistoryPrivate *priv,
  * @item: (transfer full): the #GPasteItem to add
  *
  * Add a #GPasteItem to the #GPasteHistory
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_add (GPasteHistory *self,
                      GPasteItem    *item)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
-    g_return_if_fail (G_PASTE_IS_ITEM (item));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_ITEM (item));
 
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
     guint64 max_memory = g_paste_settings_get_max_memory_usage (priv->settings) * 1024 * 1024;
 
-    g_return_if_fail (g_paste_item_get_size (item) < max_memory);
+    if (g_paste_item_get_size (item) > max_memory)
+        return;
 
-    GSList *history = priv->history;
+    GList *history = priv->history;
     gboolean election_needed = FALSE;
     GPasteUpdateTarget target = G_PASTE_UPDATE_TARGET_ALL;
 
@@ -264,7 +259,7 @@ g_paste_history_add (GPasteHistory *self,
         if (g_paste_history_private_is_growing_line (priv, old_first, item))
         {
             target = G_PASTE_UPDATE_TARGET_POSITION;
-            priv->history = g_paste_history_private_remove (priv, history, FALSE);
+            g_paste_history_private_remove (priv, history, FALSE);
         }
         else
         {
@@ -282,13 +277,12 @@ g_paste_history_add (GPasteHistory *self,
                 priv->biggest_size = size;
             }
 
-            GSList *prev = history;
             guint64 index = 1;
-            for (history = history->next; history; prev = history, history = history->next, ++index)
+            for (history = history->next; history; history = history->next, ++index)
             {
                 if (g_paste_item_equals (history->data, item) || g_paste_history_private_is_growing_line (priv, history->data, item))
                 {
-                    prev->next = g_paste_history_private_remove (priv, history, FALSE);
+                    g_paste_history_private_remove (priv, history, FALSE);
                     if (index == priv->biggest_index)
                         election_needed = TRUE;
                     break;
@@ -299,7 +293,7 @@ g_paste_history_add (GPasteHistory *self,
         }
     }
 
-    priv->history = g_slist_prepend (priv->history, item);
+    priv->history = g_list_prepend (priv->history, item);
 
     g_paste_history_activate_first (self, FALSE);
     priv->size += g_paste_item_get_size (item);
@@ -319,33 +313,28 @@ g_paste_history_add (GPasteHistory *self,
  * @index: the index of the #GPasteItem to delete
  *
  * Delete a #GPasteItem from the #GPasteHistory
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_remove (GPasteHistory *self,
                         guint64        pos)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
 
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
-    GSList *history = priv->history;
+    GList *history = priv->history;
 
     g_debug ("history: remove '%" G_GUINT64_FORMAT "'", pos);
 
-    g_return_if_fail (pos < g_slist_length (history));
+    g_return_if_fail (pos < g_list_length (history));
 
-    if (pos)
-    {
-        GSList *prev = g_slist_nth (history, pos - 1);
-        g_return_if_fail (prev);
-        prev->next = g_paste_history_private_remove (priv, g_slist_next (prev), TRUE);
-    }
-    else
-    {
-        priv->history = g_paste_history_private_remove (priv, history, TRUE);
+    GList *item = g_list_nth (history, pos);
+
+    g_return_if_fail (item);
+
+    g_paste_history_private_remove (priv, item, TRUE);
+
+    if (!pos)
         g_paste_history_activate_first (self, TRUE);
-    }
 
     if (pos == priv->biggest_index)
         g_paste_history_private_elect_new_biggest (priv);
@@ -356,15 +345,15 @@ g_paste_history_remove (GPasteHistory *self,
 }
 
 static GPasteItem *
-g_paste_history_private_get (GPasteHistoryPrivate *priv,
-                             guint64               pos)
+g_paste_history_private_get (const GPasteHistoryPrivate *priv,
+                             guint64                     pos)
 {
-    GSList *history = priv->history;
+    GList *history = priv->history;
 
-    if (pos >= g_slist_length (history))
+    if (pos >= g_list_length (history))
         return NULL;
 
-    return G_PASTE_ITEM (g_slist_nth_data (history, pos));
+    return G_PASTE_ITEM (g_list_nth_data (history, pos));
 }
 
 /**
@@ -380,9 +369,9 @@ G_PASTE_VISIBLE const GPasteItem *
 g_paste_history_get (GPasteHistory *self,
                      guint64        pos)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), NULL);
 
-    return g_paste_history_private_get (g_paste_history_get_instance_private (self), pos);
+    return g_paste_history_private_get (_g_paste_history_get_instance_private (self), pos);
 }
 
 /**
@@ -399,9 +388,9 @@ G_PASTE_VISIBLE GPasteItem *
 g_paste_history_dup (GPasteHistory *self,
                      guint64        pos)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), NULL);
 
-    return g_object_ref (g_paste_history_private_get (g_paste_history_get_instance_private (self), pos));
+    return g_object_ref (g_paste_history_private_get (_g_paste_history_get_instance_private (self), pos));
 }
 
 /**
@@ -417,9 +406,9 @@ G_PASTE_VISIBLE const gchar *
 g_paste_history_get_value (GPasteHistory *self,
                            guint64        pos)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), NULL);
 
-    GPasteItem *item = g_paste_history_private_get (g_paste_history_get_instance_private (self), pos);
+    const GPasteItem *item = g_paste_history_private_get (_g_paste_history_get_instance_private (self), pos);
     if (!item)
         return NULL;
 
@@ -439,9 +428,9 @@ G_PASTE_VISIBLE const gchar *
 g_paste_history_get_display_string (GPasteHistory *self,
                                     guint64        pos)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), NULL);
 
-    GPasteItem *item = g_paste_history_private_get (g_paste_history_get_instance_private (self), pos);
+    const GPasteItem *item = g_paste_history_private_get (_g_paste_history_get_instance_private (self), pos);
     if (!item)
         return NULL;
 
@@ -454,23 +443,21 @@ g_paste_history_get_display_string (GPasteHistory *self,
  * @index: the index of the #GPasteItem to select
  *
  * Select a #GPasteItem from the #GPasteHistory
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_select (GPasteHistory *self,
                         guint64        index)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
+
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
+    GList *history = priv->history;
 
     g_debug ("history: select '%" G_GUINT64_FORMAT "'", index);
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
-    GSList *history = priv->history;
+    g_return_if_fail (index < g_list_length (history));
 
-    g_return_if_fail (index < g_slist_length (history));
-
-    GPasteItem *item = g_slist_nth_data (history, index);
+    GPasteItem *item = g_list_nth_data (history, index);
 
     g_paste_history_add (self, item);
     g_paste_history_selected (self, item);
@@ -479,22 +466,17 @@ g_paste_history_select (GPasteHistory *self,
 static void
 _g_paste_history_replace (GPasteHistory *self,
                           guint64        index,
-                          GPasteItem    *item,
                           GPasteItem    *new,
-                          GSList        *prev,
-                          GSList        *todel)
+                          GList         *todel)
 {
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    GPasteItem *old = todel->data;
 
-    priv->size -= g_paste_item_get_size (item);
+    priv->size -= g_paste_item_get_size (old);
     priv->size += g_paste_item_get_size (new);
 
-    GSList *next = g_slist_prepend (g_slist_delete_link (todel, todel), new);
-
-    if (prev)
-        prev->next = next;
-    else
-        priv->history = next;
+    g_object_unref (old);
+    todel->data = new;
 
     if (index == priv->biggest_index)
         g_paste_history_private_elect_new_biggest (priv);
@@ -509,37 +491,31 @@ _g_paste_history_replace (GPasteHistory *self,
  * @contents: the new contents
  *
  * Replace the contents of text item at index @index
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_replace (GPasteHistory *self,
                          guint64        index,
                          const gchar   *contents)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
     g_return_if_fail (!contents || g_utf8_validate (contents, -1, NULL));
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
-    GSList *history = priv->history;
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
+    GList *history = priv->history;
 
-    g_return_if_fail (index < g_slist_length (history));
+    g_return_if_fail (index < g_list_length (history));
 
-    GSList *prev = (index) ? g_slist_nth (history, index - 1) : NULL;
-
-    g_return_if_fail (!index || prev);
-
-    GSList *todel = (index) ? g_slist_next (prev) : history;
+    GList *todel = g_list_nth (history, index);
 
     g_return_if_fail (todel);
 
     GPasteItem *item = todel->data;
 
-    g_return_if_fail (G_PASTE_IS_TEXT_ITEM (item) && !g_strcmp0 (g_paste_item_get_kind (item), "Text"));
+    g_return_if_fail (_G_PASTE_IS_TEXT_ITEM (item) && g_paste_str_equal (g_paste_item_get_kind (item), "Text"));
 
     GPasteItem *new = g_paste_text_item_new (contents);
 
-    _g_paste_history_replace (self, index, item, new, prev, todel);
+    _g_paste_history_replace (self, index, new, todel);
 
     if (!index)
         g_paste_history_selected (self, new);
@@ -552,37 +528,31 @@ g_paste_history_replace (GPasteHistory *self,
  * @name: (nullable): the name to give to the password
  *
  * Mark a text item as password
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_set_password (GPasteHistory *self,
                               guint64        index,
                               const gchar   *name)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
     g_return_if_fail (!name || g_utf8_validate (name, -1, NULL));
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
-    GSList *history = priv->history;
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
+    GList *history = priv->history;
 
-    g_return_if_fail (index < g_slist_length (history));
+    g_return_if_fail (index < g_list_length (history));
 
-    GSList *prev = (index) ? g_slist_nth (history, index - 1) : NULL;
-
-    g_return_if_fail (!index || prev);
-
-    GSList *todel = (index) ? g_slist_next (prev) : history;
+    GList *todel = g_list_nth (history, index);
 
     g_return_if_fail (todel);
 
     GPasteItem *item = todel->data;
 
-    g_return_if_fail (G_PASTE_IS_TEXT_ITEM (item) && !g_strcmp0 (g_paste_item_get_kind (item), "Text"));
+    g_return_if_fail (_G_PASTE_IS_TEXT_ITEM (item) && g_paste_str_equal (g_paste_item_get_kind (item), "Text"));
 
     GPasteItem *password = g_paste_password_item_new (name, g_paste_item_get_real_value (item));
 
-    _g_paste_history_replace (self, index, item, password, prev, todel);
+    _g_paste_history_replace (self, index, password, todel);
 }
 
 static GPasteItem *
@@ -592,11 +562,11 @@ _g_paste_history_private_get_password (const GPasteHistoryPrivate *priv,
 {
     guint64 idx = 0;
 
-    for (GSList *h = priv->history; h; h = g_slist_next (h), ++idx)
+    for (GList *h = priv->history; h; h = g_list_next (h), ++idx)
     {
         GPasteItem *i = h->data;
-        if (G_PASTE_IS_PASSWORD_ITEM (i) &&
-            !g_strcmp0 (g_paste_password_item_get_name ((GPastePasswordItem *) i), name))
+        if (_G_PASTE_IS_PASSWORD_ITEM (i) &&
+            g_paste_str_equal (g_paste_password_item_get_name ((GPastePasswordItem *) i), name))
         {
             if (index)
                 *index = idx;
@@ -616,16 +586,16 @@ _g_paste_history_private_get_password (const GPasteHistoryPrivate *priv,
  *
  * Get the first password matching name
  *
- * Returns: (optional): a #GPastePasswordItem or %NULL
+ * Returns: (nullable): a #GPastePasswordItem or %NULL
  */
 G_PASTE_VISIBLE const GPastePasswordItem *
 g_paste_history_get_password (GPasteHistory *self,
                               const gchar   *name)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), NULL);
     g_return_val_if_fail (!name || g_utf8_validate (name, -1, NULL), NULL);
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
     GPasteItem *item = _g_paste_history_private_get_password (priv, name, NULL);
 
     return (item) ? G_PASTE_PASSWORD_ITEM (item) : NULL;
@@ -637,17 +607,15 @@ g_paste_history_get_password (GPasteHistory *self,
  * @name: the name of the #GPastePasswordItem
  *
  * Delete the password matching name
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_delete_password (GPasteHistory *self,
                                  const gchar   *name)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
     g_return_if_fail (!name || g_utf8_validate (name, -1, NULL));
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
     guint64 index;
 
     if (_g_paste_history_private_get_password (priv, name, &index))
@@ -661,19 +629,17 @@ g_paste_history_delete_password (GPasteHistory *self,
  * @new_name: (nullable): the new name of the #GPastePasswordItem
  *
  * Rename the password item
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_rename_password (GPasteHistory *self,
                                  const gchar   *old_name,
                                  const gchar   *new_name)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
     g_return_if_fail (!old_name || g_utf8_validate (old_name, -1, NULL));
     g_return_if_fail (!new_name || g_utf8_validate (new_name, -1, NULL));
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
     guint64 index = 0;
     GPasteItem *item = _g_paste_history_private_get_password (priv, old_name, &index);
     if (item)
@@ -688,18 +654,15 @@ g_paste_history_rename_password (GPasteHistory *self,
  * @self: a #GPasteHistory instance
  *
  * Empty the #GPasteHistory
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_empty (GPasteHistory *self)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
 
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
 
-    g_slist_free_full (priv->history,
-                       g_object_unref);
+    g_list_free_full (priv->history, g_object_unref);
     priv->history = NULL;
     priv->size = 0;
 
@@ -784,16 +747,14 @@ ensure_history_dir_exists (gboolean save_history)
  * @name: (nullable): the name to save the history to (defaults to the configured one)
  *
  * Save the #GPasteHistory to the history file
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_save (GPasteHistory *self,
                       const gchar   *name)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
 
     GPasteSettings *settings = priv->settings;
     gboolean save_history = g_paste_settings_get_save_history (settings);
@@ -825,19 +786,19 @@ g_paste_history_save (GPasteHistory *self,
             !g_output_stream_write_all (stream, "<history version=\"1.0\">\n", 24, NULL, NULL /* cancellable */, NULL /* error */))
                 return;
 
-        for (GSList *history = priv->history; history; history = g_slist_next (history))
+        for (GList *history = priv->history; history; history = g_list_next (history))
         {
             GPasteItem *item = history->data;
             const gchar *kind = g_paste_item_get_kind (item);
 
-            if (!g_strcmp0 (kind, "Password"))
+            if (g_paste_str_equal (kind, "Password"))
                 continue;
 
             g_autofree gchar *text = g_paste_history_encode (g_paste_item_get_value (item));
 
             if (!g_output_stream_write_all (stream, "  <item kind=\"", 14, NULL, NULL /* cancellable */, NULL /* error */) ||
                 !g_output_stream_write_all (stream, kind, strlen (kind), NULL, NULL /* cancellable */, NULL /* error */) ||
-                (G_PASTE_IS_IMAGE_ITEM (item) &&
+                (_G_PASTE_IS_IMAGE_ITEM (item) &&
                     (!g_output_stream_write_all (stream, "\" date=\"", 8, NULL, NULL /* cancellable */, NULL /* error */) ||
                      !g_output_stream_write_all (stream, g_date_time_format ((GDateTime *) g_paste_image_item_get_date (G_PASTE_IMAGE_ITEM (item)), "%s"), 10, NULL, NULL /* cancellable */, NULL /* error */))) ||
                 !g_output_stream_write_all (stream, "\"><![CDATA[", 11, NULL, NULL /* cancellable */, NULL /* error */) ||
@@ -909,31 +870,31 @@ start_tag (GMarkupParseContext *context G_GNUC_UNUSED,
 {
     Data *data = user_data;
 
-    if (!g_strcmp0 (element_name, "history"))
+    if (g_paste_str_equal (element_name, "history"))
     {
         SWITCH_STATE (BEGIN, IN_HISTORY);
     }
-    else if (!g_strcmp0 (element_name, "item"))
+    else if (g_paste_str_equal (element_name, "item"))
     {
         SWITCH_STATE (IN_HISTORY, IN_ITEM);
         g_clear_pointer (&data->date, g_free);
         g_clear_pointer (&data->text, g_free);
         for (const gchar **a = attribute_names, **v = attribute_values; *a && *v; ++a, ++v)
         {
-            if (!g_strcmp0 (*a, "kind"))
+            if (g_paste_str_equal (*a, "kind"))
             {
-                if (!g_strcmp0 (*v, "Text"))
+                if (g_paste_str_equal (*v, "Text"))
                     data->type = TEXT;
-                else if (!g_strcmp0 (*v, "Image"))
+                else if (g_paste_str_equal (*v, "Image"))
                     data->type = IMAGE;
-                else if (!g_strcmp0 (*v, "Uris"))
+                else if (g_paste_str_equal (*v, "Uris"))
                     data->type = URIS;
-                else if (!g_strcmp0 (*v, "Password"))
+                else if (g_paste_str_equal (*v, "Password"))
                     data->type = PASSWORD;
                 else
                     g_critical ("Unknown item kind: %s", *v);
             }
-            else if (!g_strcmp0 (*a, "date"))
+            else if (g_paste_str_equal (*a, "date"))
             {
                 if (data->type != IMAGE)
                 {
@@ -942,7 +903,7 @@ start_tag (GMarkupParseContext *context G_GNUC_UNUSED,
                 }
                 data->date = g_strdup (*v);
             }
-            else if (!g_strcmp0 (*a, "name"))
+            else if (g_paste_str_equal (*a, "name"))
             {
                 if (data->type != PASSWORD)
                 {
@@ -967,11 +928,11 @@ end_tag (GMarkupParseContext *context G_GNUC_UNUSED,
 {
     Data *data = user_data;
 
-    if (!g_strcmp0 (element_name, "history"))
+    if (g_paste_str_equal (element_name, "history"))
     {
         SWITCH_STATE (IN_HISTORY, END);
     }
-    else if (!g_strcmp0 (element_name, "item"))
+    else if (g_paste_str_equal (element_name, "item"))
     {
         SWITCH_STATE (HAS_TEXT, IN_HISTORY);
     }
@@ -1046,7 +1007,7 @@ on_text (GMarkupParseContext *context G_GNUC_UNUSED,
                 {
                     GPasteHistoryPrivate *priv = data->priv;
                     priv->size += g_paste_item_get_size (item);
-                    priv->history = g_slist_append (priv->history, item);
+                    priv->history = g_list_append (priv->history, item);
                     ++data->current_size;;
                 }
             }
@@ -1077,24 +1038,22 @@ static void on_error (GMarkupParseContext *context   G_GNUC_UNUSED,
  * @name: (nullable): the name of the history to load, defaults to the configured one
  *
  * Load the #GPasteHistory from the history file
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_load (GPasteHistory *self,
                       const gchar   *name)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
     g_return_if_fail (!name || g_utf8_validate (name, -1, NULL));
 
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
     GPasteSettings *settings = priv->settings;
 
-    if (priv->name && !g_strcmp0(name, priv->name))
+    if (priv->name && g_paste_str_equal(name, priv->name))
         return;
 
-    g_slist_free_full (priv->history,
-                       g_object_unref);
+    g_list_free_full (priv->history,
+                      g_object_unref);
     priv->history = NULL;
 
     g_free (priv->name);
@@ -1159,18 +1118,16 @@ g_paste_history_load (GPasteHistory *self,
  * @name: the name of the new history
  *
  * Switch to a new history
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_switch (GPasteHistory *self,
                         const gchar   *name)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
     g_return_if_fail (name);
     g_return_if_fail (g_utf8_validate (name, -1, NULL));
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
 
     g_paste_settings_set_history_name (priv->settings, name);
 }
@@ -1182,21 +1139,19 @@ g_paste_history_switch (GPasteHistory *self,
  * @error: a #GError
  *
  * Delete the current #GPasteHistory
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_history_delete (GPasteHistory *self,
                         const gchar   *name,
                         GError       **error)
 {
-    g_return_if_fail (G_PASTE_IS_HISTORY (self));
+    g_return_if_fail (_G_PASTE_IS_HISTORY (self));
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
 
     g_autoptr (GFile) history_file = g_paste_history_get_history_file ((name) ? name : priv->name);
 
-    if (!g_strcmp0 (name, priv->name))
+    if (g_paste_str_equal (name, priv->name))
         g_paste_history_empty (self);
 
     if (g_file_query_exists (history_file,
@@ -1211,7 +1166,7 @@ g_paste_history_delete (GPasteHistory *self,
 static void
 g_paste_history_history_name_changed (GPasteHistory *self)
 {
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
 
     g_debug ("history: name cahnged to '%s'", priv->name);
 
@@ -1229,11 +1184,11 @@ g_paste_history_settings_changed (GPasteSettings *settings G_GNUC_UNUSED,
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
 
     /* FIXME: track text item size settings */
-    if (!g_strcmp0(key, G_PASTE_MAX_HISTORY_SIZE_SETTING))
+    if (g_paste_str_equal(key, G_PASTE_MAX_HISTORY_SIZE_SETTING))
         g_paste_history_private_check_size (priv);
-    else if (!g_strcmp0 (key, G_PASTE_MAX_MEMORY_USAGE_SETTING))
+    else if (g_paste_str_equal (key, G_PASTE_MAX_MEMORY_USAGE_SETTING))
         g_paste_history_private_check_memory_usage (priv);
-    else if (!g_strcmp0 (key, G_PASTE_HISTORY_NAME_SETTING))
+    else if (g_paste_str_equal (key, G_PASTE_HISTORY_NAME_SETTING))
         g_paste_history_history_name_changed (self);
 }
 
@@ -1241,12 +1196,12 @@ static void
 g_paste_history_dispose (GObject *object)
 {
     GPasteHistory *self = G_PASTE_HISTORY (object);
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
     GPasteSettings *settings = priv->settings;
 
     if (settings)
     {
-        g_signal_handler_disconnect (settings, priv->changed_signal);
+        g_signal_handler_disconnect (settings, priv->c_signals[C_CHANGED]);
         g_clear_object (&priv->settings);
     }
 
@@ -1256,11 +1211,10 @@ g_paste_history_dispose (GObject *object)
 static void
 g_paste_history_finalize (GObject *object)
 {
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (G_PASTE_HISTORY (object));
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (G_PASTE_HISTORY (object));
 
     g_free (priv->name);
-    g_slist_free_full (priv->history,
-                       g_object_unref);
+    g_list_free_full (priv->history, g_object_unref);
 
     G_OBJECT_CLASS (g_paste_history_parent_class)->finalize (object);
 }
@@ -1340,9 +1294,6 @@ g_paste_history_init (GPasteHistory *self)
 {
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
 
-    priv->history = NULL;
-    priv->size = 0;
-
     g_paste_history_private_elect_new_biggest (priv);
 }
 
@@ -1354,12 +1305,12 @@ g_paste_history_init (GPasteHistory *self)
  *
  * Returns: (element-type GPasteItem) (transfer none): The inner history
  */
-G_PASTE_VISIBLE const GSList *
+G_PASTE_VISIBLE const GList *
 g_paste_history_get_history (const GPasteHistory *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), NULL);
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
 
     return priv->history;
 }
@@ -1375,11 +1326,11 @@ g_paste_history_get_history (const GPasteHistory *self)
 G_PASTE_VISIBLE guint64
 g_paste_history_get_length (const GPasteHistory *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), 0);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), 0);
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
 
-    return g_slist_length (priv->history);
+    return g_list_length (priv->history);
 }
 
 /**
@@ -1393,9 +1344,9 @@ g_paste_history_get_length (const GPasteHistory *self)
 G_PASTE_VISIBLE const gchar *
 g_paste_history_get_current (const GPasteHistory *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), 0);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), 0);
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
 
     return priv->name;
 }
@@ -1413,12 +1364,12 @@ G_PASTE_VISIBLE GArray *
 g_paste_history_search (const GPasteHistory *self,
                         const gchar         *pattern)
 {
-    g_return_val_if_fail (G_PASTE_IS_HISTORY (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_HISTORY (self), NULL);
     g_return_val_if_fail (pattern && g_utf8_validate (pattern, -1, NULL), NULL);
 
     g_debug ("history: search '%s'", pattern);
 
-    GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
+    const GPasteHistoryPrivate *priv = _g_paste_history_get_instance_private (self);
     g_autoptr (GError) error = NULL;
     g_autoptr (GRegex) regex = g_regex_new (pattern,
                                             G_REGEX_CASELESS|G_REGEX_MULTILINE|G_REGEX_DOTALL|G_REGEX_OPTIMIZE,
@@ -1463,7 +1414,7 @@ g_paste_history_search (const GPasteHistory *self,
                                    sizeof (guint64));
     guint64 index = 0;
 
-    for (GSList *history = priv->history; history; history = g_slist_next (history), ++index)
+    for (GList *history = priv->history; history; history = g_list_next (history), ++index)
     {
         if (include_idx && idx == index)
             g_array_append_val (results, index);
@@ -1486,16 +1437,16 @@ g_paste_history_search (const GPasteHistory *self,
 G_PASTE_VISIBLE GPasteHistory *
 g_paste_history_new (GPasteSettings *settings)
 {
-    g_return_val_if_fail (G_PASTE_IS_SETTINGS (settings), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_SETTINGS (settings), NULL);
 
     GPasteHistory *self = g_object_new (G_PASTE_TYPE_HISTORY, NULL);
     GPasteHistoryPrivate *priv = g_paste_history_get_instance_private (self);
 
     priv->settings = g_object_ref (settings);
-    priv->changed_signal = g_signal_connect (settings,
-                                             "changed",
-                                             G_CALLBACK (g_paste_history_settings_changed),
-                                             self);
+    priv->c_signals[C_CHANGED] = g_signal_connect (settings,
+                                                   "changed",
+                                                   G_CALLBACK (g_paste_history_settings_changed),
+                                                   self);
 
     return self;
 }
