@@ -1,25 +1,12 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include "gpaste-bus-object.h"
 
-G_DEFINE_ABSTRACT_TYPE (GPasteBusObject, g_paste_bus_object, G_TYPE_OBJECT)
+G_PASTE_DEFINE_ABSTRACT_TYPE (BusObject, bus_object, G_TYPE_OBJECT)
 
 /**
  * g_paste_bus_object_register_on_connection:
@@ -36,7 +23,7 @@ g_paste_bus_object_register_on_connection (GPasteBusObject *self,
                                            GDBusConnection *connection,
                                            GError         **error)
 {
-    g_return_val_if_fail (G_PASTE_IS_BUS_OBJECT (self), FALSE);
+    g_return_val_if_fail (_G_PASTE_IS_BUS_OBJECT (self), FALSE);
     g_return_val_if_fail (G_IS_DBUS_CONNECTION (connection), FALSE);
     g_return_val_if_fail (!error || !(*error), FALSE);
 
