@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2013-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include "gpaste-gdbus-macros.h"
@@ -58,7 +45,7 @@ struct _GPasteGnomeShellClient
     GDBusProxy parent_instance;
 };
 
-G_DEFINE_TYPE (GPasteGnomeShellClient, g_paste_gnome_shell_client, G_TYPE_DBUS_PROXY)
+G_PASTE_DEFINE_TYPE (GnomeShellClient, gnome_shell_client, G_TYPE_DBUS_PROXY)
 
 enum
 {
@@ -198,8 +185,6 @@ g_paste_gnome_shell_client_ungrab_accelerator_sync (GPasteGnomeShellClient *self
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Grab a keybinding
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_gnome_shell_client_grab_accelerator (GPasteGnomeShellClient     *self,
@@ -223,8 +208,6 @@ g_paste_gnome_shell_client_grab_accelerator (GPasteGnomeShellClient     *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Grab some keybindings
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_gnome_shell_client_grab_accelerators (GPasteGnomeShellClient      *self,
@@ -259,8 +242,6 @@ g_paste_gnome_shell_client_grab_accelerators (GPasteGnomeShellClient      *self,
  * @user_data: (nullable): The data to pass to @callback.
  *
  * Ungrab a keybinding
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_gnome_shell_client_ungrab_accelerator (GPasteGnomeShellClient *self,
@@ -337,7 +318,7 @@ g_paste_gnome_shell_client_g_signal (GDBusProxy  *proxy,
 {
     GPasteGnomeShellClient *self = G_PASTE_GNOME_SHELL_CLIENT (proxy);
 
-    if (!g_strcmp0 (signal_name, G_PASTE_GNOME_SHELL_SIG_ACCELERATOR_ACTIVATED))
+    if (g_paste_str_equal (signal_name, G_PASTE_GNOME_SHELL_SIG_ACCELERATOR_ACTIVATED))
     {
         GVariantIter params_iter;
         g_variant_iter_init (&params_iter, parameters);
@@ -408,8 +389,6 @@ g_paste_gnome_shell_client_new_sync (GError **error)
  * @user_data: User data to pass to @callback.
  *
  * Create a new instance of #GPasteGnomeShellClient
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_gnome_shell_client_new (GAsyncReadyCallback callback,
