@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2013-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #if !defined (__G_PASTE_H_INSIDE__) && !defined (G_PASTE_COMPILATION)
@@ -89,7 +76,7 @@ G_BEGIN_DECLS
 /*****************************/
 
 #define DBUS_CALL_ASYNC_FULL(TYPE_CHECKER, decl, method, params, n_params) \
-    g_return_if_fail (G_PASTE_IS_##TYPE_CHECKER (self));                   \
+    g_return_if_fail (_G_PASTE_IS_##TYPE_CHECKER (self));                   \
     decl;                                                                  \
     g_dbus_proxy_call (G_DBUS_PROXY(self),                                 \
                        method,                                             \
@@ -131,7 +118,7 @@ G_BEGIN_DECLS
     DBUS_RETURN (if_fail, extract_and_return_answer)
 
 #define DBUS_ASYNC_FINISH_WITH_RETURN(TYPE_CHECKER, if_fail, extract_and_return_answer)                \
-    DBUS_ASYNC_FINISH_FULL (g_return_val_if_fail (G_PASTE_IS_##TYPE_CHECKER (self), if_fail);          \
+    DBUS_ASYNC_FINISH_FULL (g_return_val_if_fail (_G_PASTE_IS_##TYPE_CHECKER (self), if_fail);          \
                             g_return_val_if_fail (G_IS_ASYNC_RESULT (result), if_fail);                \
                             g_return_val_if_fail (!error || !(*error), if_fail),                       \
                             if_fail,                                                                   \
@@ -143,7 +130,7 @@ G_BEGIN_DECLS
 /***********************************/
 
 #define DBUS_ASYNC_FINISH_NO_RETURN_BASE(TYPE_CHECKER)                           \
-    DBUS_ASYNC_FINISH_FULL (g_return_if_fail (G_PASTE_IS_##TYPE_CHECKER (self)); \
+    DBUS_ASYNC_FINISH_FULL (g_return_if_fail (_G_PASTE_IS_##TYPE_CHECKER (self)); \
                             g_return_if_fail (G_IS_ASYNC_RESULT (result));       \
                             g_return_if_fail (!error || !(*error)), ;, {})
 
@@ -189,14 +176,14 @@ G_BEGIN_DECLS
 /****************************************/
 
 #define DBUS_CALL_NO_RETURN_BASE(TYPE_CHECKER, decl, method, params, n_params) \
-    DBUS_CALL_FULL (g_return_if_fail (G_PASTE_IS_##TYPE_CHECKER (self)), decl, method, params, n_params, ;, {})
+    DBUS_CALL_FULL (g_return_if_fail (_G_PASTE_IS_##TYPE_CHECKER (self)), decl, method, params, n_params, ;, {})
 
 /******************************************/
 /* Methods / Sync / General - With return */
 /******************************************/
 
 #define DBUS_CALL_WITH_RETURN_FULL_BASE(TYPE_CHECKER, decl, method, params, n_params, if_fail, variant_extract, pre_extract)                        \
-    DBUS_CALL_FULL (g_return_val_if_fail (G_PASTE_IS_##TYPE_CHECKER (self), if_fail), decl, method, params, n_params, if_fail, \
+    DBUS_CALL_FULL (g_return_val_if_fail (_G_PASTE_IS_##TYPE_CHECKER (self), if_fail), decl, method, params, n_params, if_fail, \
                     pre_extract;                                                                                                                    \
                     variant_extract)
 
@@ -291,7 +278,7 @@ G_BEGIN_DECLS
 /************************/
 
 #define DBUS_GET_PROPERTY_INIT(TYPE_CHECKER, property,  _default)                        \
-    g_return_val_if_fail (G_PASTE_IS_##TYPE_CHECKER (self), _default);                   \
+    g_return_val_if_fail (_G_PASTE_IS_##TYPE_CHECKER (self), _default);                   \
     g_autoptr (GVariant) result = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (self), \
                                                                     property);           \
     if (!result)                                                                         \
@@ -310,7 +297,7 @@ G_BEGIN_DECLS
 /************************/
 
 #define DBUS_SET_GENERIC_PROPERTY_BASE(TYPE_CHECKER, iface, property, value, vtype)              \
-    g_return_val_if_fail (G_PASTE_IS_##TYPE_CHECKER (self), FALSE);                              \
+    g_return_val_if_fail (_G_PASTE_IS_##TYPE_CHECKER (self), FALSE);                              \
     GVariant *prop[] = {                                                                         \
         g_variant_new_string (iface),                                                            \
         g_variant_new_string (property),                                                         \
