@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2013-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include <gpaste-settings-ui-widget.h>
@@ -29,7 +16,7 @@ typedef struct
     GPasteSettingsUiStack *stack;
 } GPasteSettingsUiWidgetPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (GPasteSettingsUiWidget, g_paste_settings_ui_widget, GTK_TYPE_GRID)
+G_PASTE_DEFINE_TYPE_WITH_PRIVATE (SettingsUiWidget, settings_ui_widget, GTK_TYPE_GRID)
 
 /**
  * g_paste_settings_ui_widget_get_stack:
@@ -42,9 +29,9 @@ G_DEFINE_TYPE_WITH_PRIVATE (GPasteSettingsUiWidget, g_paste_settings_ui_widget,
 G_PASTE_VISIBLE GPasteSettingsUiStack *
 g_paste_settings_ui_widget_get_stack (GPasteSettingsUiWidget *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_SETTINGS_UI_WIDGET (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_SETTINGS_UI_WIDGET (self), NULL);
 
-    GPasteSettingsUiWidgetPrivate *priv = g_paste_settings_ui_widget_get_instance_private (self);
+    const GPasteSettingsUiWidgetPrivate *priv = _g_paste_settings_ui_widget_get_instance_private (self);
 
     return priv->stack;
 }
@@ -80,14 +67,14 @@ g_paste_settings_ui_widget_init (GPasteSettingsUiWidget *self)
  *
  * Create a new instance of #GPasteSettingsUiWidget
  *
- * Returns: (optional): a newly allocated #GPasteSettingsUiWidget
+ * Returns: (nullable): a newly allocated #GPasteSettingsUiWidget
  *                      free it with g_object_unref
  */
 G_PASTE_VISIBLE GtkWidget *
 g_paste_settings_ui_widget_new (void)
 {
     GtkWidget *self = gtk_widget_new (G_PASTE_TYPE_SETTINGS_UI_WIDGET, NULL);
-    GPasteSettingsUiWidgetPrivate *priv = g_paste_settings_ui_widget_get_instance_private (G_PASTE_SETTINGS_UI_WIDGET (self));
+    const GPasteSettingsUiWidgetPrivate *priv = _g_paste_settings_ui_widget_get_instance_private (G_PASTE_SETTINGS_UI_WIDGET (self));
 
     if (!priv->stack)
     {
