@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include <gpaste-ui-upload-item.h>
@@ -24,7 +11,7 @@ struct _GPasteUiUploadItem
     GPasteUiItemAction parent_instance;
 };
 
-G_DEFINE_TYPE (GPasteUiUploadItem, g_paste_ui_upload_item, G_PASTE_TYPE_UI_ITEM_ACTION)
+G_PASTE_DEFINE_TYPE (UiUploadItem, ui_upload_item, G_PASTE_TYPE_UI_ITEM_ACTION)
 
 static void
 g_paste_ui_upload_item_activate (GPasteUiItemAction *self G_GNUC_UNUSED,
@@ -57,7 +44,7 @@ g_paste_ui_upload_item_init (GPasteUiUploadItem *self G_GNUC_UNUSED)
 G_PASTE_VISIBLE GtkWidget *
 g_paste_ui_upload_item_new (GPasteClient *client)
 {
-    g_return_val_if_fail (G_PASTE_IS_CLIENT (client), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_CLIENT (client), NULL);
 
     return g_paste_ui_item_action_new (G_PASTE_TYPE_UI_UPLOAD_ITEM, client, "document-send-symbolic", _("Upload"));
 }
