@@ -263,7 +263,7 @@ g_paste_ui_window_new (GtkApplication *app)
                                       "type",            GTK_WINDOW_TOPLEVEL,
                                       "window-position", GTK_WIN_POS_CENTER_ALWAYS,
                                       "resizable",       FALSE,
-                                      "icon-name",       "edit-paste",
+                                      "icon-name",       G_PASTE_ICON_NAME,
                                       NULL);
 
     g_paste_client_new (on_client_ready, self);
